import { createElement as _createElement } from "react";
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import React from 'react';
import { isEqual } from 'lodash';
import { ArrowDropDown as ArrowDropDownIcon } from '@mui/icons-material';
import { Close as CloseIcon } from '@mui/icons-material';
import { Autocomplete, Box, Chip, TextField, Typography, } from '@mui/material';
import CrossIcon from '../../assets/icons/cross.svg';
import InfoIcon from '../../assets/icons/info.svg';
import { VariantTypes } from '../../constants/common-constants';
import { translate } from '../../locales/translations';
import AdminTooltip from '../tooltip/AdminTooltip';
import './adminDropdown-styles.scss';
const AdminDropdown = (props) => {
    const { containerClass = '', data, disabled, helperText = '', error = false, isMultiple = false, isOptional = false, isReadOnly = false, label = '', labelClass = '', maxSelectLimit, placeholder = 'Select an option...', renderOption = defaultRenderOption, onChange = () => { }, value = null, tooltipMessage, } = props;
    function defaultRenderOption(props, option) {
        const { label } = option;
        return (_jsx(Box, { component: "li", ...props, className: "adminDropdown__optionContainer", children: _jsx(Typography, { className: "adminDropdown__optionLabel", children: label }) }));
    }
    const renderInput = (params) => (_jsx(TextField, { ...params, inputProps: {
            ...params.inputProps,
            placeholder: isMultiple ? '' : placeholder,
        }, variant: VariantTypes.Outlined, className: `adminDropdown__textfield ${helperText ? 'adminDropdown__errorField' : ''}`, helperText: error && helperText ? helperText : '', error: error }));
    const handleChange = (_event, newValue, _changeReason, details) => {
        if (_changeReason === 'clear') {
            onChange(null);
            return;
        }
        let updatedValues = [];
        if (isMultiple && Array.isArray(newValue)) {
            const { option } = details || {};
            const selectedValues = new Set(value); // Use Set for unique values
            if (option) {
                // Toggle the selection of the option
                if (selectedValues.has(option.id)) {
                    selectedValues.delete(option.id); // Remove if already selected
                }
                else {
                    selectedValues.add(option.id); // Add if not selected
                }
            }
            // Convert Set back to array and check limit
            updatedValues = Array.from(selectedValues);
            if (maxSelectLimit && updatedValues.length > maxSelectLimit) {
                updatedValues = updatedValues.slice(0, maxSelectLimit);
            }
        }
        else {
            const singleValue = newValue;
            updatedValues.push(singleValue.id);
        }
        onChange(updatedValues.length ? updatedValues : null);
    };
    const renderChipsTags = (value, getTagProps) => {
        return value?.map((option, index) => {
            console.log('option', option);
            return (_createElement(Chip, { ...getTagProps({ index }), label: option.label, key: option.id, deleteIcon: _jsx(CrossIcon, {}), className: "adminDropdown__chip" }));
        });
    };
    const getValue = () => {
        let res = null;
        if (isMultiple && Array.isArray(value)) {
            const multipleValue = value;
            res = data.filter(eachItem => multipleValue.includes(eachItem.id ?? ''));
        }
        else {
            const singleValue = value;
            res = data.find(eachItem => eachItem.id === singleValue);
        }
        return res;
    };
    const getOptionDisabled = (option) => {
        const isMaxLimitReached = !!maxSelectLimit && Array.isArray(value) && value.length >= maxSelectLimit;
        const selectedValues = getValue();
        const isSameTypeSelected = Array.isArray(value) &&
            selectedValues?.some((selectedOption) => selectedOption?.type === option?.type);
        return isMaxLimitReached || option.isDisabled || isSameTypeSelected || false;
    };
    return (_jsxs("div", { className: `adminDropdown__container ${containerClass}`, children: [_jsxs(Typography, { className: labelClass, children: [label, !!tooltipMessage && (_jsx(AdminTooltip, { message: tooltipMessage, isDarkMode: true, children: _jsx(InfoIcon, {}) })), isOptional && (_jsx("span", { className: "adminDropdown__optionalLabel", children: translate.common.optional }))] }), _jsx(Autocomplete, { autoComplete: true, autoHighlight: true, className: "adminDropdown__Dropdown", clearIcon: _jsx(CloseIcon, { onClick: e => {
                        handleChange(e, null, 'clear');
                    }, fontSize: "small" }), getOptionLabel: option => option.label, getOptionDisabled: getOptionDisabled, multiple: isMultiple, onChange: handleChange, options: data, popupIcon: _jsx(ArrowDropDownIcon, {}), readOnly: isReadOnly, renderInput: renderInput, renderOption: renderOption, renderTags: renderChipsTags, value: getValue(), disabled: disabled })] }));
};
const arePropsEqual = (prevProps, nextProps) => {
    return isEqual(prevProps, nextProps);
};
export default React.memo(AdminDropdown, arePropsEqual);
